==> haskell-src-1.0.4.1-54-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-src
version:              1.0.4.1
visibility:           public
id:                   haskell-src-1.0.4.1-FJsMgTqV7PL3vyhtClnn0S
key:                  haskell-src-1.0.4.1-FJsMgTqV7PL3vyhtClnn0S
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Simon Marlow, Sven Panne and Noel Winstanley
stability:            stable
synopsis:             Support for manipulating Haskell source code
description:
    The @haskell-src@ package provides support for manipulating Haskell
    source code. The package provides a lexer, parser and
    pretty-printer, and a definition of a Haskell abstract syntax tree
    (AST). Common uses of this package are to parse or generate
    <http://www.haskell.org/onlinereport/ Haskell 98> code.

category:             Language
abi:                  a03cc38b39fac8d0be81b35bdf8c8472
exposed:              True
exposed-modules:
    Language.Haskell.Lexer Language.Haskell.ParseMonad
    Language.Haskell.ParseUtils Language.Haskell.Parser
    Language.Haskell.Pretty Language.Haskell.Syntax

import-dirs:          /usr/lib/ghc-9.4.8/site-local/haskell-src-1.0.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/haskell-src-1.0.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/haskell-src-1.0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src
hs-libraries:         HShaskell-src-1.0.4.1-FJsMgTqV7PL3vyhtClnn0S
depends:
    array-0.5.4.0 base-4.17.2.1 pretty-1.1.3.6
    syb-0.7.3-6VXQKmiHaWYG9qlQr6p3GQ

haddock-interfaces:   /usr/share/doc/haskell-src/html/haskell-src.haddock
haddock-html:         /usr/share/doc/haskell-src/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-1.0.4.1-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-src
version:              1.0.4.1
visibility:           public
id:                   haskell-src-1.0.4.1-3ce4ctqEQnCIGHXQw177KL
key:                  haskell-src-1.0.4.1-3ce4ctqEQnCIGHXQw177KL
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Simon Marlow, Sven Panne and Noel Winstanley
stability:            stable
synopsis:             Support for manipulating Haskell source code
description:
    The @haskell-src@ package provides support for manipulating Haskell
    source code. The package provides a lexer, parser and
    pretty-printer, and a definition of a Haskell abstract syntax tree
    (AST). Common uses of this package are to parse or generate
    <http://www.haskell.org/onlinereport/ Haskell 98> code.

category:             Language
abi:                  bc85822a58f74f030fc3850f15faaeb2
exposed:              True
exposed-modules:
    Language.Haskell.Lexer Language.Haskell.ParseMonad
    Language.Haskell.ParseUtils Language.Haskell.Parser
    Language.Haskell.Pretty Language.Haskell.Syntax

import-dirs:          /usr/lib/ghc-9.4.8/site-local/haskell-src-1.0.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/haskell-src-1.0.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/haskell-src-1.0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src
hs-libraries:         HShaskell-src-1.0.4.1-3ce4ctqEQnCIGHXQw177KL
depends:
    array-0.5.4.0 base-4.17.2.1 pretty-1.1.3.6
    syb-0.7.3-BQUcn35RmaZ45KQPDd3rN

haddock-interfaces:   /usr/share/doc/haskell-src/html/haskell-src.haddock
haddock-html:         /usr/share/doc/haskell-src/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
